@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -38,6 +38,7 @@ import org.ojalgo.function.aggregator.AggregatorSet;
 import org.ojalgo.function.special.PowerOf2;
 import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
+import org.ojalgo.structure.Factory1D;
 import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.structure.StructureAnyD;
 import org.ojalgo.type.math.MathType;
@@ -56,37 +57,30 @@ import org.ojalgo.type.math.MathType;
 public abstract class BasicArray<N extends Comparable<N>> implements Access1D<N>, Access1D.Aggregatable<N>, Access1D.Visitable<N>, Mutate1D,
         Mutate1D.Fillable<N>, Mutate1D.Modifiable<N>, Access1D.Collectable<N, Mutate1D> {
 
-    public static final class Factory<N extends Comparable<N>> extends ArrayFactory<N, BasicArray<N>> {
+    public static final class Factory<N extends Comparable<N>> extends BaseFactory<N, BasicArray<N>> {
 
-        private static final long SPARSE_SEGMENTATION_LIMIT = PowerOf2.powerOfLong2(46);
+        private final DenseArray.Factory<N, ?> myDenseFactory;
+        private final GrowthStrategy myDenseStrategy;
+        private final GrowthStrategy mySparseStrategy;
 
-        private final DenseArray.Factory<N> myDenseFactory;
-        private final GrowthStrategy myGrowthStrategy;
+        Factory(final DenseArray.Factory<N, ?> denseFactory) {
+
+            super(denseFactory.getMathType());
 
-        Factory(final org.ojalgo.array.DenseArray.Factory<N> denseFactory) {
-            super();
             myDenseFactory = denseFactory;
-            myGrowthStrategy = GrowthStrategy.newInstance(denseFactory);
+
+            myDenseStrategy = GrowthStrategy.from(denseFactory.getMathType()).segment(PowerOf2.powerOfLong2(23));
+            mySparseStrategy = GrowthStrategy.from(denseFactory.getMathType()).segment(PowerOf2.powerOfLong2(46));
         }
 
         @Override
-        public AggregatorSet<N> aggregator() {
-            return myDenseFactory.aggregator();
+        public BasicArray<N> make(final int size) {
+            return this.makeToBeFilled(size);
         }
 
         @Override
-        public FunctionSet<N> function() {
-            return myDenseFactory.function();
-        }
-
-        @Override
-        public MathType getMathType() {
-            return myDenseFactory.getMathType();
-        }
-
-        @Override
-        public Scalar.Factory<N> scalar() {
-            return myDenseFactory.scalar();
+        public BasicArray<N> make(final long size) {
+            return this.makeStructuredZero(size);
         }
 
         @Override
@@ -94,18 +88,20 @@ public abstract class BasicArray<N extends Comparable<N>> implements Access1D<N>
             return Long.MAX_VALUE;
         }
 
-        @Override
+        /**
+         * Most likely sparse, and then also segmented.
+         */
         BasicArray<N> makeStructuredZero(final long... structure) {
 
             long total = StructureAnyD.count(structure);
 
-            if (total > SPARSE_SEGMENTATION_LIMIT) {
+            if (mySparseStrategy.isSegmented(total)) {
 
-                return this.makeSegmented(structure);
+                return SegmentedArray.newInstance(this, structure);
 
-            } else if (myGrowthStrategy.isChunked(total)) {
+            } else if (mySparseStrategy.isChunked(total) && myDenseFactory instanceof PlainArray.Factory) {
 
-                return new SparseArray<>(myDenseFactory, myGrowthStrategy, total);
+                return new SparseArray<>((PlainArray.Factory<N, ?>) myDenseFactory, mySparseStrategy, Math.toIntExact(total));
 
             } else {
 
@@ -113,13 +109,15 @@ public abstract class BasicArray<N extends Comparable<N>> implements Access1D<N>
             }
         }
 
-        @Override
+        /**
+         * Maybe segmented, but dense.
+         */
         BasicArray<N> makeToBeFilled(final long... structure) {
 
             long total = StructureAnyD.count(structure);
 
-            if (myGrowthStrategy.isSegmented(total)) {
-                return myDenseFactory.makeSegmented(total);
+            if (myDenseStrategy.isSegmented(total)) {
+                return SegmentedArray.newInstance(this, total);
             } else {
                 return myDenseFactory.make(total);
             }
@@ -127,14 +125,62 @@ public abstract class BasicArray<N extends Comparable<N>> implements Access1D<N>
 
     }
 
-    private final ArrayFactory<N, ?> myFactory;
+    abstract static class BaseFactory<N extends Comparable<N>, A extends BasicArray<N>> implements Factory1D<A> {
+
+        private final AggregatorSet<N> myAggregator;
+        private final FunctionSet<N> myFunction;
+        private final MathType myMathType;
+        private final Scalar.Factory<N> myScalar;
+
+        BaseFactory(final MathType mathType) {
+
+            super();
+
+            myMathType = mathType;
+
+            myScalar = myMathType.getScalarFactory();
+            myFunction = myMathType.getFunctionSet();
+            myAggregator = myFunction.aggregator();
+        }
+
+        public final AggregatorSet<N> aggregator() {
+            return myAggregator;
+        }
+
+        @Override
+        public final FunctionSet<N> function() {
+            return myFunction;
+        }
+
+        @Override
+        public final MathType getMathType() {
+            return myMathType;
+        }
+
+        @Override
+        public final Scalar.Factory<N> scalar() {
+            return myScalar;
+        }
+
+        /**
+         * Max number of elements in this array.
+         */
+        abstract long getCapacityLimit();
+
+        final long getElementSize() {
+            return myMathType.getTotalMemory();
+        }
+
+    }
+
+    private final BaseFactory<N, ?> myFactory;
 
     @SuppressWarnings("unused")
     private BasicArray() {
         this(null);
     }
 
-    protected BasicArray(final ArrayFactory<N, ?> factory) {
+    protected BasicArray(final BaseFactory<N, ?> factory) {
         super();
         myFactory = factory;
     }
@@ -292,7 +338,7 @@ public abstract class BasicArray<N extends Comparable<N>> implements Access1D<N>
         return new ArrayAnyD<>(this, structure);
     }
 
-    final ArrayFactory<N, ?> factory() {
+    final BaseFactory<N, ?> factory() {
         return myFactory;
     }
 
