@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,12 +21,14 @@
  */
 package org.ojalgo.array;
 
+import org.ojalgo.OjAlgoUtils;
 import org.ojalgo.function.BinaryFunction;
 import org.ojalgo.function.NullaryFunction;
 import org.ojalgo.function.UnaryFunction;
 import org.ojalgo.function.VoidFunction;
 import org.ojalgo.function.special.PowerOf2;
 import org.ojalgo.structure.Access1D;
+import org.ojalgo.structure.StructureAnyD;
 import org.ojalgo.type.NumberDefinition;
 
 /**
@@ -41,9 +43,37 @@ import org.ojalgo.type.NumberDefinition;
  */
 final class SegmentedArray<N extends Comparable<N>> extends BasicArray<N> {
 
+    static <N extends Comparable<N>> SegmentedArray<N> newInstance(final BaseFactory<N, ?> segmentFactory, final long... structure) {
+
+        long totalCount = StructureAnyD.count(structure);
+
+        int max = PowerOf2.powerOf2Smaller(totalCount);
+        int min = PowerOf2.powerOf2Larger(totalCount / PlainArray.MAX_SIZE);
+
+        if (min > max) {
+            throw new IllegalArgumentException();
+        }
+
+        int indexBits = Math.max(min, max - OjAlgoUtils.ENVIRONMENT.cores);
+        long segmentSize = 1L << indexBits; // 2^bits
+        int nbUniformSegments = Math.toIntExact(totalCount / segmentSize);
+        long remainder = totalCount % segmentSize;
+        int nbTotalSegments = remainder == 0L ? nbUniformSegments : nbUniformSegments + 1;
+
+        BasicArray<N>[] segments = (BasicArray<N>[]) new BasicArray<?>[nbTotalSegments];
+        for (int s = 0; s < nbUniformSegments; s++) {
+            segments[s] = segmentFactory.make(segmentSize);
+        }
+        if (remainder != 0L) {
+            segments[nbUniformSegments] = segmentFactory.make(remainder);
+        }
+
+        return new SegmentedArray<>(segments, segmentFactory);
+    }
+
     private final int myIndexBits;
     private final long myIndexMask;
-    private final ArrayFactory<N, ?> mySegmentFactory;
+    private final BasicArray.BaseFactory<N, ?> mySegmentFactory;
     private final BasicArray<N>[] mySegments;
 
     /**
@@ -52,58 +82,21 @@ final class SegmentedArray<N extends Comparable<N>> extends BasicArray<N> {
      */
     private final long mySegmentSize;
 
-    SegmentedArray(final BasicArray<N>[] segments, final ArrayFactory<N, ?> segmentFactory) {
+    SegmentedArray(final BasicArray<N>[] segments, final BasicArray.BaseFactory<N, ?> segmentFactory) {
 
         super(segmentFactory);
 
         mySegmentSize = segments[0].count();
-        int tmpIndexOfLastSegment = segments.length - 1;
-        for (int s = 1; s < tmpIndexOfLastSegment; s++) {
-            if (segments[s].count() != mySegmentSize) {
-                throw new IllegalArgumentException("All segments (except possibly the last) must have the same size!");
-            }
-        }
-        if (segments[tmpIndexOfLastSegment].count() > mySegmentSize) {
-            throw new IllegalArgumentException("The last segment cannot be larger than the others!");
-        }
-
         myIndexBits = PowerOf2.find(mySegmentSize);
-        if (myIndexBits < 0 || mySegmentSize != 1L << myIndexBits) {
-            throw new IllegalArgumentException("The segment size must be a power of 2!");
-        }
-
         myIndexMask = mySegmentSize - 1L;
 
         mySegments = segments;
         mySegmentFactory = segmentFactory;
     }
 
-    @SuppressWarnings("unchecked")
-    SegmentedArray(final long count, final int indexBits, final ArrayFactory<N, ?> segmentFactory) {
-
-        super(segmentFactory);
-
-        long tmpSegmentSize = 1L << indexBits; // 2^bits
-
-        int tmpNumberOfUniformSegments = (int) (count / tmpSegmentSize);
-        long tmpRemainder = count % tmpSegmentSize;
-
-        int tmpTotalNumberOfSegments = tmpRemainder == 0L ? (int) tmpNumberOfUniformSegments : tmpNumberOfUniformSegments + 1;
-
-        mySegments = (BasicArray<N>[]) new BasicArray<?>[tmpTotalNumberOfSegments];
-        for (int s = 0; s < tmpNumberOfUniformSegments; s++) {
-            mySegments[s] = segmentFactory.makeStructuredZero(tmpSegmentSize);
-        }
-        if (tmpRemainder != 0L) {
-            mySegments[tmpNumberOfUniformSegments] = segmentFactory.makeStructuredZero(tmpRemainder);
-        }
-
-        mySegmentSize = tmpSegmentSize;
-
-        myIndexBits = indexBits;
-        myIndexMask = tmpSegmentSize - 1L;
-
-        mySegmentFactory = segmentFactory;
+    @Override
+    public void add(final int index, final double addend) {
+        mySegments[index >> myIndexBits].add(index & myIndexMask, addend);
     }
 
     @Override
@@ -431,38 +424,40 @@ final class SegmentedArray<N extends Comparable<N>> extends BasicArray<N> {
 
     /**
      * Will either grow the last segment to be the same size as all the others, or add another segment (with
-     * the same size). The returned (could be the same) instance is guaranteed to have a last segement of the
+     * the same size). The returned (could be the same) instance is guaranteed to have a last segment of the
      * same size as the others and at least one more "space" in that segment.
      */
     SegmentedArray<N> grow() {
 
-        BasicArray<N> tmpLastSegment = mySegments[mySegments.length - 1];
+        int last = mySegments.length - 1;
+
+        BasicArray<N> tmpLastSegment = mySegments[last];
         BasicArray<N> tmpNewSegment = mySegmentFactory.make(mySegmentSize);
 
         long tmpLastSegmentSize = tmpLastSegment.count();
 
         if (tmpLastSegmentSize < mySegmentSize) {
 
-            mySegments[mySegments.length - 1] = tmpNewSegment;
+            mySegments[last] = tmpNewSegment;
 
             tmpNewSegment.fillMatching(tmpLastSegment);
 
             return this;
 
-        }
-        if (tmpLastSegmentSize != mySegmentSize) {
+        } else {
 
-            throw new IllegalStateException();
-        }
-        @SuppressWarnings("unchecked")
-        BasicArray<N>[] tmpSegments = (BasicArray<N>[]) new BasicArray<?>[mySegments.length + 1];
+            if (tmpLastSegmentSize != mySegmentSize) {
+                throw new IllegalStateException();
+            }
 
-        for (int i = 0; i < mySegments.length; i++) {
-            tmpSegments[i] = mySegments[i];
-        }
-        tmpSegments[mySegments.length] = tmpNewSegment;
+            BasicArray<N>[] segments = (BasicArray<N>[]) new BasicArray<?>[mySegments.length + 1];
+            for (int i = 0; i < mySegments.length; i++) {
+                segments[i] = mySegments[i];
+            }
+            segments[mySegments.length] = tmpNewSegment;
 
-        return new SegmentedArray<>(tmpSegments, mySegmentFactory);
+            return new SegmentedArray<>(segments, mySegmentFactory);
+        }
     }
 
 }
