@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@ import java.util.function.IntSupplier;
 import org.ojalgo.OjAlgoUtils;
 
 /**
- * A set of standard levels of parallelsim derived from the number of available cores and optionally capped by
+ * A set of standard levels of parallelism derived from the number of available cores and optionally capped by
  * reserving a specified amount of memory per thread. The info about available cores/threads/memory comes from
  * {@link OjAlgoUtils#ENVIRONMENT}.
  */
@@ -68,6 +68,7 @@ public enum Parallelism implements ParallelismSupplier {
         myValue = value;
     }
 
+    @Override
     public int getAsInt() {
         return myValue.getAsInt();
     }
