@@ -1,3 +1,24 @@
+/*
+ * Copyright 1997-2025 Optimatika
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ */
 package org.ojalgo.concurrent;
 
 import java.util.ArrayList;
@@ -211,6 +232,9 @@ public final class ProcessingService {
                 future.get();
             }
         } catch (InterruptedException | ExecutionException cause) {
+            if (cause instanceof InterruptedException) {
+                Thread.currentThread().interrupt();
+            }
             throw new RuntimeException(cause);
         }
     }
@@ -301,6 +325,9 @@ public final class ProcessingService {
                 partialResults.reset();
             }
         } catch (InterruptedException | ExecutionException cause) {
+            if (cause instanceof InterruptedException) {
+                Thread.currentThread().interrupt();
+            }
             throw new RuntimeException(cause);
         }
 
@@ -357,6 +384,9 @@ public final class ProcessingService {
                 partialResults.reset();
             }
         } catch (InterruptedException | ExecutionException cause) {
+            if (cause instanceof InterruptedException) {
+                Thread.currentThread().interrupt();
+            }
             throw new RuntimeException(cause);
         }
 
@@ -398,6 +428,9 @@ public final class ProcessingService {
                 future.get();
             }
         } catch (InterruptedException | ExecutionException cause) {
+            if (cause instanceof InterruptedException) {
+                Thread.currentThread().interrupt();
+            }
             throw new RuntimeException(cause);
         }
     }
@@ -418,6 +451,9 @@ public final class ProcessingService {
             future1.get();
             future2.get();
         } catch (InterruptedException | ExecutionException cause) {
+            if (cause instanceof InterruptedException) {
+                Thread.currentThread().interrupt();
+            }
             throw new RuntimeException(cause);
         }
     }
@@ -465,4 +501,4 @@ public final class ProcessingService {
         return this.take(queue, parallelism.getAsInt(), processor);
     }
 
-}
+}
\ No newline at end of file
