@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -336,16 +336,14 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
                         output.set(i, ComplexNumber.of(workRe[i], -workIm[i]));
                     }
                 }
+            } else if (scale) {
+                double divisor = size;
+                for (int i = 0; i < size; i++) {
+                    output.set(i, ComplexNumber.of(workRe[i] / divisor, workIm[i] / divisor));
+                }
             } else {
-                if (scale) {
-                    double divisor = size;
-                    for (int i = 0; i < size; i++) {
-                        output.set(i, ComplexNumber.of(workRe[i] / divisor, workIm[i] / divisor));
-                    }
-                } else {
-                    for (int i = 0; i < size; i++) {
-                        output.set(i, ComplexNumber.of(workRe[i], workIm[i]));
-                    }
+                for (int i = 0; i < size; i++) {
+                    output.set(i, ComplexNumber.of(workRe[i], workIm[i]));
                 }
             }
         }
@@ -425,7 +423,7 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
                 FFT.doStages(myStages, myUnitRoots, myWorkRe, myWorkIm);
             }
 
-            PhysicalStore<ComplexNumber> output = GenericStore.C128.makeDense(input.length, 1);
+            PhysicalStore<ComplexNumber> output = GenericStore.C128.make(input.length, 1);
 
             FFT.toOutput(myWorkRe, myWorkIm, DEFAULT.conjugate, DEFAULT.scale, output);
 
@@ -500,7 +498,7 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
 
     public static MatrixStore<ComplexNumber> inverse2D(final MatrixStore<?> input) {
 
-        PhysicalStore<ComplexNumber> retVal = GenericStore.C128.makeDense(input.getRowDim(), input.getColDim());
+        PhysicalStore<ComplexNumber> retVal = GenericStore.C128.make(input.getRowDim(), input.getColDim());
 
         DiscreteFourierTransform.transform2D(input, INVERSE, retVal);
 
@@ -535,7 +533,7 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
 
     public static MatrixC128 newVandermondeMatrix(final int size) {
 
-        DenseReceiver receiver = MatrixC128.FACTORY.makeDense(size, size);
+        DenseReceiver receiver = MatrixC128.FACTORY.newDenseBuilder(size, size);
 
         DiscreteFourierTransform.generate(receiver);
 
@@ -613,7 +611,7 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
      */
     public static MatrixStore<ComplexNumber> transform2D(final MatrixStore<?> input) {
 
-        PhysicalStore<ComplexNumber> retVal = GenericStore.C128.makeDense(input.getRowDim(), input.getColDim());
+        PhysicalStore<ComplexNumber> retVal = GenericStore.C128.make(input.getRowDim(), input.getColDim());
 
         DiscreteFourierTransform.transform2D(input, DEFAULT, retVal);
 
@@ -626,7 +624,7 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
         int nbCols = input.getColDim();
 
         DiscreteFourierTransform transformer = DiscreteFourierTransform.newInstance(nbRows);
-        PhysicalStore<ComplexNumber> workOutput = GenericStore.C128.makeDense(nbRows, 1);
+        PhysicalStore<ComplexNumber> workOutput = GenericStore.C128.make(nbRows, 1);
 
         Directive directive1 = directive;
         for (ColumnView<?> view : input.columns()) {
@@ -636,7 +634,7 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
 
         if (nbRows != nbCols) {
             transformer = DiscreteFourierTransform.newInstance(nbCols);
-            workOutput = GenericStore.C128.makeDense(nbCols, 1);
+            workOutput = GenericStore.C128.make(nbCols, 1);
         }
 
         Directive directive2 = directive.withComplex(true);
@@ -656,38 +654,35 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
 
             return UNIT_ROOTS[exponent];
 
+        } else if (exponent == 0) {
+
+            return UNIT_ROOTS[0] = new ComplexNumber[] { ComplexNumber.ONE };
+
+        } else if (exponent == 1) {
+
+            return UNIT_ROOTS[1] = new ComplexNumber[] { ComplexNumber.ONE, ComplexNumber.NEG };
+
+        } else if (exponent == 2) {
+
+            return UNIT_ROOTS[2] = new ComplexNumber[] { ComplexNumber.ONE, ComplexNumber.N, ComplexNumber.NEG, ComplexNumber.I };
+
         } else {
 
-            if (exponent == 0) {
+            ComplexNumber[] half = DiscreteFourierTransform.lookupRootsExponent(exponent - 1);
 
-                return UNIT_ROOTS[0] = new ComplexNumber[] { ComplexNumber.ONE };
+            ComplexNumber[] full = UNIT_ROOTS[exponent] = new ComplexNumber[half.length + half.length];
 
-            } else if (exponent == 1) {
+            ComplexNumber[] unitRoots = ComplexNumber.newUnitRoots(full.length);
 
-                return UNIT_ROOTS[1] = new ComplexNumber[] { ComplexNumber.ONE, ComplexNumber.NEG };
+            for (int i = 0; i < half.length; i++) {
+                int ii = 2 * i;
+                int ii1 = ii + 1;
 
-            } else if (exponent == 2) {
-
-                return UNIT_ROOTS[2] = new ComplexNumber[] { ComplexNumber.ONE, ComplexNumber.N, ComplexNumber.NEG, ComplexNumber.I };
-
-            } else {
-
-                ComplexNumber[] half = DiscreteFourierTransform.lookupRootsExponent(exponent - 1);
-
-                ComplexNumber[] full = UNIT_ROOTS[exponent] = new ComplexNumber[half.length + half.length];
-
-                ComplexNumber[] unitRoots = ComplexNumber.newUnitRoots(full.length);
-
-                for (int i = 0; i < half.length; i++) {
-                    int ii = 2 * i;
-                    int ii1 = ii + 1;
-
-                    full[ii] = half[i];
-                    full[ii1] = unitRoots[ii1];
-                }
-
-                return full;
+                full[ii] = half[i];
+                full[ii1] = unitRoots[ii1];
             }
+
+            return full;
         }
     }
 
@@ -772,14 +767,14 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
     }
 
     public final MatrixStore<ComplexNumber> inverse(final Access1D<ComplexNumber> input) {
-        PhysicalStore<ComplexNumber> output = GenericStore.C128.makeDense(input.size(), 1);
+        PhysicalStore<ComplexNumber> output = GenericStore.C128.make(input.size(), 1);
         this.transform(input, INVERSE, output);
         return output;
     }
 
     @Override
     public final MatrixStore<ComplexNumber> transform(final Access1D<?> input) {
-        PhysicalStore<ComplexNumber> output = GenericStore.C128.makeDense(input.size(), 1);
+        PhysicalStore<ComplexNumber> output = GenericStore.C128.make(input.size(), 1);
         this.transform(input, DEFAULT, output);
         return output;
     }
@@ -791,7 +786,7 @@ public abstract class DiscreteFourierTransform implements DataTransform<Access1D
     }
 
     public MatrixStore<ComplexNumber> transform(final double... input) {
-        PhysicalStore<ComplexNumber> output = GenericStore.C128.makeDense(input.length, 1);
+        PhysicalStore<ComplexNumber> output = GenericStore.C128.make(input.length, 1);
         this.transform(ArrayR064.wrap(input), DEFAULT, output);
         return output;
     }
