@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,8 +21,7 @@
  */
 package org.ojalgo.equation;
 
-import static org.ojalgo.function.constant.PrimitiveMath.ONE;
-import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
+import static org.ojalgo.function.constant.PrimitiveMath.*;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -30,9 +29,11 @@ import java.util.List;
 import org.ojalgo.array.ArrayR064;
 import org.ojalgo.array.BasicArray;
 import org.ojalgo.array.DenseArray;
+import org.ojalgo.array.PlainArray;
 import org.ojalgo.array.SparseArray;
 import org.ojalgo.function.UnaryFunction;
 import org.ojalgo.structure.Access1D;
+import org.ojalgo.structure.ElementView1D;
 import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.type.NumberDefinition;
 
@@ -42,7 +43,7 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
         return Equation.dense(pivot, cols, ArrayR064.FACTORY);
     }
 
-    public static <N extends Comparable<N>> Equation dense(final int pivot, final int cols, final DenseArray.Factory<N> factory) {
+    public static <N extends Comparable<N>> Equation dense(final int pivot, final int cols, final DenseArray.Factory<N, ?> factory) {
         return new Equation(factory.make(cols), pivot, ZERO);
     }
 
@@ -50,7 +51,7 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
         return Equation.denseSystem(rows, cols, ArrayR064.FACTORY);
     }
 
-    public static <N extends Comparable<N>> List<Equation> denseSystem(final int rows, final int cols, final DenseArray.Factory<N> factory) {
+    public static <N extends Comparable<N>> List<Equation> denseSystem(final int rows, final int cols, final DenseArray.Factory<N, ?> factory) {
 
         List<Equation> system = new ArrayList<>(rows);
 
@@ -69,23 +70,28 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
         return Equation.sparse(pivot, cols, ArrayR064.FACTORY);
     }
 
-    public static <N extends Comparable<N>> Equation sparse(final int pivot, final int cols, final DenseArray.Factory<N> factory) {
+    public static Equation sparse(final int pivot, final int cols, final int numberOfNonzeros) {
+        return Equation.sparse(pivot, cols, ArrayR064.FACTORY, numberOfNonzeros);
+    }
+
+    public static <N extends Comparable<N>> Equation sparse(final int pivot, final int cols, final PlainArray.Factory<N, ?> factory) {
         return new Equation(SparseArray.factory(factory).make(cols), pivot, ZERO);
     }
 
-    public static <N extends Comparable<N>> Equation sparse(final int pivot, final int cols, final DenseArray.Factory<N> factory, final int numberOfNonzeros) {
+    public static <N extends Comparable<N>> Equation sparse(final int pivot, final int cols, final PlainArray.Factory<N, ?> factory,
+            final int numberOfNonzeros) {
         return new Equation(SparseArray.factory(factory).initial(numberOfNonzeros).make(cols), pivot, ZERO);
     }
 
-    public static Equation sparse(final int pivot, final int cols, final int numberOfNonzeros) {
-        return Equation.sparse(pivot, cols, ArrayR064.FACTORY, numberOfNonzeros);
-    }
-
     public static List<Equation> sparseSystem(final int rows, final int cols) {
         return Equation.sparseSystem(rows, cols, ArrayR064.FACTORY);
     }
 
-    public static <N extends Comparable<N>> List<Equation> sparseSystem(final int rows, final int cols, final DenseArray.Factory<N> factory) {
+    public static List<Equation> sparseSystem(final int rows, final int cols, final int numberOfNonzeros) {
+        return Equation.sparseSystem(rows, cols, ArrayR064.FACTORY, numberOfNonzeros);
+    }
+
+    public static <N extends Comparable<N>> List<Equation> sparseSystem(final int rows, final int cols, final PlainArray.Factory<N, ?> factory) {
 
         List<Equation> system = new ArrayList<>(rows);
 
@@ -96,7 +102,7 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
         return system;
     }
 
-    public static <N extends Comparable<N>> List<Equation> sparseSystem(final int rows, final int cols, final DenseArray.Factory<N> factory,
+    public static <N extends Comparable<N>> List<Equation> sparseSystem(final int rows, final int cols, final PlainArray.Factory<N, ?> factory,
             final int numberOfNonzeros) {
 
         List<Equation> system = new ArrayList<>(rows);
@@ -108,10 +114,6 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
         return system;
     }
 
-    public static List<Equation> sparseSystem(final int rows, final int cols, final int numberOfNonzeros) {
-        return Equation.sparseSystem(rows, cols, ArrayR064.FACTORY, numberOfNonzeros);
-    }
-
     public static Equation wrap(final BasicArray<?> body, final int pivot, final double rhs) {
         return new Equation(body, pivot, rhs);
     }
@@ -139,22 +141,24 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
     }
 
     @Override
-    public void add(final long ind, final Comparable<?> addend) {
-        this.add(ind, NumberDefinition.doubleValue(addend));
-    }
-
-    @Override
-    public void add(final long ind, final double addend) {
+    public void add(final int ind, final double addend) {
         myBody.add(ind, addend);
         if (ind == index) {
             myPivot = myBody.doubleValue(ind);
         }
     }
 
+    @Override
+    public void add(final long ind, final Comparable<?> addend) {
+        this.add(ind, NumberDefinition.doubleValue(addend));
+    }
+
     /**
      * Will perform a (relaxed) GaussSeidel update.
+     * <p>
+     * This call will not work if the pivot (the element at {@link #index}) is zero!
      *
-     * @param x The current solution (one element will be updated)
+     * @param x          The current solution (one element will be updated)
      * @param relaxation Typically 1.0 but could be anything (Most likely should be between 0.0 and 2.0).
      * @return The error in this equation
      */
@@ -177,6 +181,68 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
         return myBody.dot(vector);
     }
 
+    /**
+     * Efficiently compute sum_{j < pivot} a_{ij} * x_j (excludes the pivot). Uses direct sparse iteration
+     * when available to avoid O(n) random access scans.
+     */
+    public double dotLower(final Access1D<?> x) {
+
+        double retVal = ZERO;
+
+        if (myBody instanceof SparseArray) {
+
+            for (ElementView1D<?, ?> nz : myBody.nonzeros()) {
+                int j = (int) nz.index();
+                if (j >= index) {
+                    break;
+                }
+                retVal += nz.doubleValue() * x.doubleValue(j);
+            }
+
+        } else {
+
+            for (int j = 0; j < index; j++) {
+                double aij = myBody.doubleValue(j);
+                if (aij != ZERO) {
+                    retVal += aij * x.doubleValue(j);
+                }
+            }
+        }
+
+        return retVal;
+    }
+
+    /**
+     * Efficiently compute sum_{j > pivot} a_{ij} * x_j (excludes the pivot). Uses direct sparse iteration
+     * when available to avoid O(n) random access scans.
+     */
+    public double dotUpper(final Access1D<?> x) {
+
+        double retVal = ZERO;
+
+        if (myBody instanceof SparseArray) {
+
+            for (ElementView1D<?, ?> nz : myBody.nonzeros()) {
+                int j = (int) nz.index();
+                if (j <= index) {
+                    continue;
+                }
+                retVal += nz.doubleValue() * x.doubleValue(j);
+            }
+
+        } else {
+
+            for (int j = index + 1, limit = myBody.size(); j < limit; j++) {
+                double aij = myBody.doubleValue(j);
+                if (aij != ZERO) {
+                    retVal += aij * x.doubleValue(j);
+                }
+            }
+        }
+
+        return retVal;
+    }
+
     @Override
     public double doubleValue(final int ind) {
         return myBody.doubleValue(ind);
@@ -231,6 +297,13 @@ public final class Equation implements Comparable<Equation>, Access1D<Double>, M
         return prime * result + index;
     }
 
+    /**
+     * Initialises the solution vector's element at {@link #index} to the value that would solve this equation
+     * if the RHS was zero and all other elements in the solution vector unchanged.
+     *
+     * @param <T> The solution vector type
+     * @param x   The solution vector to be initialised
+     */
     public <T extends Access1D<Double> & Mutate1D.Modifiable<Double>> void initialise(final T x) {
         this.calculate(x, ZERO, ONE);
     }
