@@ -36,7 +36,10 @@ public class BasicMachine {
             return false;
         }
         BasicMachine other = (BasicMachine) obj;
-        if ((memory != other.memory) || (threads != other.threads)) {
+        if (memory != other.memory) {
+            return false;
+        }
+        if (threads != other.threads) {
             return false;
         }
         return true;
@@ -47,7 +50,8 @@ public class BasicMachine {
         final int prime = 31;
         int result = 1;
         result = prime * result + (int) (memory ^ (memory >>> 32));
-        return prime * result + threads;
+        result = prime * result + threads;
+        return result;
     }
 
     @Override
@@ -81,4 +85,5 @@ public class BasicMachine {
         }
 
     }
+
 }
