@@ -41,7 +41,6 @@ import org.ojalgo.scalar.ComplexNumber;
 import org.ojalgo.scalar.Quadruple;
 import org.ojalgo.scalar.Quaternion;
 import org.ojalgo.scalar.RationalNumber;
-import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
 import org.ojalgo.structure.Access2D.Collectable;
@@ -299,35 +298,35 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
             switch (kase) { // Perform the task indicated by kase.
 
-            // s[p] and e[k-1] are negligible and k<p
-            case 1: // Deflate negligible s[p]
+                // s[p] and e[k-1] are negligible and k<p
+                case 1: // Deflate negligible s[p]
 
-                DenseSingularValue.doCase1(s, e, p, k, q2RotR);
-                break;
+                    DenseSingularValue.doCase1(s, e, p, k, q2RotR);
+                    break;
 
-            // s[k] is negligible and k<p
-            case 2: // Split at negligible s[k]
+                // s[k] is negligible and k<p
+                case 2: // Split at negligible s[k]
 
-                DenseSingularValue.doCase2(s, e, p, k, q1RotR);
-                break;
+                    DenseSingularValue.doCase2(s, e, p, k, q1RotR);
+                    break;
 
-            // e[k-1] is negligible, k<p, and s(k)...s(p) are not negligible
-            case 3: // Perform QR-step.
+                // e[k-1] is negligible, k<p, and s(k)...s(p) are not negligible
+                case 3: // Perform QR-step.
 
-                DenseSingularValue.doCase3(s, e, p, k, q1RotR, q2RotR);
-                break;
+                    DenseSingularValue.doCase3(s, e, p, k, q1RotR, q2RotR);
+                    break;
 
-            // e[p-1] is negligible
-            case 4: // Convergence
+                // e[p-1] is negligible
+                case 4: // Convergence
 
-                DenseSingularValue.doCase4(s, k, q2NegCol, q1XchgCols, q2XchgCols);
-                p--;
-                break;
+                    DenseSingularValue.doCase4(s, k, q2NegCol, q1XchgCols, q2XchgCols);
+                    p--;
+                    break;
 
-            // Should never happen
-            default:
+                // Should never happen
+                default:
 
-                throw new IllegalStateException();
+                    throw new IllegalStateException();
 
             } // switch
         } // while
@@ -335,7 +334,6 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
     private double[] e = null;
     private final DenseBidiagonal<N> myBidiagonal;
-    private transient MatrixStore<N> myD = null;
     private final boolean myFullSize;
     private final Structure2D myInputStructure = new Structure2D() {
 
@@ -350,6 +348,7 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
         }
     };
     private transient MatrixStore<N> myInverse = null;
+    private transient MatrixStore<N> myS = null;
     private transient Array1D<Double> mySingularValues = null;
     private boolean myTransposed = false;
     private transient MatrixStore<N> myU = null;
@@ -366,6 +365,13 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
         myFullSize = fullSize;
     }
 
+    @Override
+    public void btran(final double[] arg) {
+        DecompositionStore<N> x = this.copyRow(arg);
+        this.btran(x);
+        x.supplyTo(arg);
+    }
+
     @Override
     public final void btran(final PhysicalStore<N> arg) {
         arg.fillByMultiplying(this.getInverse().transpose(), arg.copy());
@@ -392,6 +398,13 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
         return this.compute(matrix, false, this.isFullSize());
     }
 
+    @Override
+    public void ftran(final double[] arg) {
+        DecompositionStore<N> x = this.copyColumn(arg);
+        this.ftran(x);
+        x.supplyTo(arg);
+    }
+
     @Override
     public int getColDim() {
         return myTransposed ? myBidiagonal.getRowDim() : myBidiagonal.getColDim();
@@ -399,17 +412,14 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
     @Override
     public double getCondition() {
-
-        final Array1D<Double> tmpSingularValues = this.getSingularValues();
-
-        return tmpSingularValues.doubleValue(0) / tmpSingularValues.doubleValue(tmpSingularValues.length - 1);
+        return s[0] / s[s.length - 1];
     }
 
     @Override
     public MatrixStore<N> getCovariance() {
 
         MatrixStore<N> v = this.getV();
-        MatrixStore<N> d = this.getD();
+        MatrixStore<N> d = this.getS();
         Access1D<N> values = d.sliceDiagonal();
 
         int rank = this.getRank();
@@ -421,14 +431,13 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
         return tmp.multiply(tmp.transpose());
     }
 
+    /**
+     * @deprecated Use {@link #getS()} instead
+     */
+    @Deprecated
     @Override
     public MatrixStore<N> getD() {
-
-        if (this.isComputed() && myD == null) {
-            myD = this.makeD();
-        }
-
-        return myD;
+        return this.getS();
     }
 
     @Override
@@ -436,11 +445,9 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
         double retVal = ZERO;
 
-        final Array1D<Double> tmpSingularValues = this.getSingularValues();
         double tmpVal;
-
-        for (int i = tmpSingularValues.size() - 1; i >= 0; i--) {
-            tmpVal = tmpSingularValues.doubleValue(i);
+        for (int i = s.length - 1; i >= 0; i--) {
+            tmpVal = s[i];
             retVal += tmpVal * tmpVal;
         }
 
@@ -449,30 +456,22 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
     @Override
     public MatrixStore<N> getInverse() {
-        return this.getInverse(this.preallocate(myInputStructure));
+
+        if (myInverse == null) {
+            int nbRows = this.getRowDim();
+            int nbCols = this.getColDim();
+            PhysicalStore<N> preallocated = this.preallocate(nbRows, nbCols, nbRows);
+            myInverse = SingularValue.invert(this, preallocated);
+        }
+
+        return myInverse;
     }
 
     @Override
     public MatrixStore<N> getInverse(final PhysicalStore<N> preallocated) {
 
         if (myInverse == null) {
-
-            int rank = this.getRank();
-
-            MatrixStore<N> tmpV = this.getV();
-            PhysicalStore<N> tmpMtrx = tmpV.limits(-1, rank).collect(tmpV.physical());
-
-            Scalar.Factory<N> scalar = this.scalar();
-            BinaryFunction<N> divide = this.function().divide();
-
-            Array1D<Double> singularValues = this.getSingularValues();
-            for (int j = 0; j < rank; j++) {
-                tmpMtrx.modifyColumn(0L, j, divide.by(scalar.cast(singularValues.doubleValue(j))));
-            }
-
-            preallocated.fillByMultiplying(tmpMtrx, this.getU().limits(-1, rank).conjugate());
-
-            myInverse = preallocated;
+            myInverse = SingularValue.invert(this, preallocated);
         }
 
         return myInverse;
@@ -481,12 +480,10 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
     @Override
     public double getKyFanNorm(final int k) {
 
-        final Array1D<Double> tmpSingularValues = this.getSingularValues();
-
         double retVal = ZERO;
 
-        for (int i = Math.min(tmpSingularValues.size(), k) - 1; i >= 0; i--) {
-            retVal += tmpSingularValues.doubleValue(i);
+        for (int i = Math.min(s.length, k) - 1; i >= 0; i--) {
+            retVal += s[i];
         }
 
         return retVal;
@@ -494,7 +491,7 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
     @Override
     public double getOperatorNorm() {
-        return this.getSingularValues().doubleValue(0);
+        return s[0];
     }
 
     @Override
@@ -507,6 +504,16 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
         return myTransposed ? myBidiagonal.getColDim() : myBidiagonal.getRowDim();
     }
 
+    @Override
+    public MatrixStore<N> getS() {
+
+        if (this.isComputed() && myS == null) {
+            myS = this.makeD();
+        }
+
+        return myS;
+    }
+
     @Override
     public Array1D<Double> getSingularValues() {
 
@@ -519,13 +526,27 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
     @Override
     public MatrixStore<N> getSolution(final Collectable<N, ? super PhysicalStore<N>> rhs, final PhysicalStore<N> preallocated) {
-        preallocated.fillByMultiplying(this.getInverse(), this.collect(rhs));
-        return preallocated;
+
+        MatrixStore<N> mRHS = this.collect(rhs);
+
+        if (myInverse != null) {
+            preallocated.fillByMultiplying(myInverse, mRHS);
+            return preallocated;
+        }
+
+        if (this.isComputed() && !myValuesOnly) {
+
+            return SingularValue.solve(this, mRHS, preallocated);
+
+        } else {
+
+            throw new IllegalStateException();
+        }
     }
 
     @Override
     public double getTraceNorm() {
-        return this.getKyFanNorm(this.getSingularValues().size());
+        return this.getKyFanNorm(s.length);
     }
 
     @Override
@@ -546,7 +567,7 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
     @Override
     public MatrixStore<N> getV() {
 
-        if (!myValuesOnly && this.isComputed() && myV == null) {
+        if (this.isComputed() && !myValuesOnly && myV == null) {
             if (myTransposed) {
                 myV = myBidiagonal.doGetLQ();
             } else {
@@ -612,7 +633,7 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
 
         myBidiagonal.reset();
 
-        myD = null;
+        myS = null;
         myU = null;
         myV = null;
         mySingularValues = null;
@@ -762,12 +783,4 @@ abstract class DenseSingularValue<N extends Comparable<N>> extends AbstractDecom
         return Array1D.R064.wrap(ArrayR064.wrap(s));
     }
 
-    void setD(final MatrixStore<N> someD) {
-        myD = someD;
-    }
-
-    void setSingularValues(final Array1D<Double> singularValues) {
-        mySingularValues = singularValues;
-    }
-
 }
