@@ -52,6 +52,13 @@ final class RawLU extends RawDecomposition implements LU<Double> {
         super();
     }
 
+    @Override
+    public void btran(final double[] arg) {
+        DecompositionStore<Double> x = this.copyRow(arg);
+        this.btran(x);
+        x.supplyTo(arg);
+    }
+
     @Override
     public void btran(final PhysicalStore<Double> arg) {
 
@@ -115,6 +122,13 @@ final class RawLU extends RawDecomposition implements LU<Double> {
         return this.doDecompose(data, false);
     }
 
+    @Override
+    public void ftran(final double[] arg) {
+        DecompositionStore<Double> x = this.copyColumn(arg);
+        this.ftran(x);
+        x.supplyTo(arg);
+    }
+
     @Override
     public void ftran(final PhysicalStore<Double> arg) {
 
