@@ -67,6 +67,21 @@ final class SparseLU extends AbstractDecomposition<Double, R064Store> implements
             myElements = SparseArray.factory(ArrayR064.FACTORY).make(dim);
         }
 
+        @Override
+        public void btran(final double[] arg) {
+
+            double rowValue = arg[myTo];
+            for (NonzeroView<Double> nz : myElements.nonzeros()) {
+                arg[(int) nz.index()] += nz.doubleValue() * rowValue;
+            }
+
+            double tmp = arg[myTo];
+            for (int i = myTo; i > myFrom; i--) {
+                arg[i] = arg[i - 1];
+            }
+            arg[myFrom] = tmp;
+        }
+
         @Override
         public void btran(final PhysicalStore<Double> arg) {
 
@@ -82,6 +97,22 @@ final class SparseLU extends AbstractDecomposition<Double, R064Store> implements
             arg.set(myFrom, tmp);
         }
 
+        @Override
+        public void ftran(final double[] arg) {
+
+            double tmp = arg[myFrom];
+            for (int i = myFrom; i < myTo; i++) {
+                arg[i] = arg[i + 1];
+            }
+            arg[myTo] = tmp;
+
+            double sum = ZERO;
+            for (NonzeroView<Double> nz : myElements.nonzeros()) {
+                sum += nz.doubleValue() * arg[(int) nz.index()];
+            }
+            arg[myTo] += sum;
+        }
+
         @Override
         public void ftran(final PhysicalStore<Double> arg) {
 
@@ -154,6 +185,13 @@ final class SparseLU extends AbstractDecomposition<Double, R064Store> implements
         myColPivot = null;
     }
 
+    @Override
+    public void btran(final double[] arg) {
+        DecompositionStore<Double> x = this.copyRow(arg);
+        this.btran(x);
+        x.supplyTo(arg);
+    }
+
     @Override
     public void btran(final PhysicalStore<Double> arg) {
 
@@ -258,6 +296,13 @@ final class SparseLU extends AbstractDecomposition<Double, R064Store> implements
         return this.computed(true);
     }
 
+    @Override
+    public void ftran(final double[] arg) {
+        DecompositionStore<Double> x = this.copyColumn(arg);
+        this.ftran(x);
+        x.supplyTo(arg);
+    }
+
     @Override
     public void ftran(final PhysicalStore<Double> arg) {
 
@@ -345,9 +390,7 @@ final class SparseLU extends AbstractDecomposition<Double, R064Store> implements
 
         } else {
 
-            for (int col = 0; col < nbSolutions; col++) {
-                this.ftranInternal(preallocated);
-            }
+            this.ftranInternal(preallocated);
         }
 
         if (myColPivot != null) {
