@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,9 +23,7 @@ package org.ojalgo.matrix.decomposition.function;
 
 public interface RotateRight {
 
-    RotateRight NULL = (low, high, cos, sin) -> {
-
-    };
+    RotateRight NULL = (low, high, cos, sin) -> {};
 
     void rotateRight(int low, int high, double cos, double sin);
 
