@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -26,6 +26,7 @@ import java.util.function.IntSupplier;
 
 import org.ojalgo.array.operation.AXPY;
 import org.ojalgo.array.operation.DOT;
+import org.ojalgo.array.operation.FillAll;
 import org.ojalgo.concurrent.DivideAndConquer;
 import org.ojalgo.concurrent.DivideAndConquer.Conquerer;
 import org.ojalgo.concurrent.Parallelism;
@@ -60,7 +61,30 @@ public class MultiplyNeither implements MatrixOperation {
     public static IntSupplier PARALLELISM = Parallelism.THREADS;
     public static int THRESHOLD = 32;
 
-    private static final DivideAndConquer.Divider DIVIDER = ProcessingService.INSTANCE.divider();
+    private static final DivideAndConquer.Divider DIVIDER = ProcessingService.INSTANCE.newDivider();
+
+    public static void add(final double[][] product, final double[][] left, final double[][] right) {
+
+        DIVIDER.divide(product.length, (first, limit) -> {
+
+            for (int i = first; i < limit; i++) {
+                MultiplyNeither.doOneRow(product[i], left[i], right);
+            }
+        });
+    }
+
+    public static void fill(final double[][] product, final double[][] left, final double[][] right) {
+
+        DIVIDER.divide(product.length, (first, limit) -> {
+
+            for (int i = first; i < limit; i++) {
+                double[] prodRow = product[i];
+                FillAll.fill(prodRow, 0, prodRow.length, 1, 0D);
+                MultiplyNeither.doOneRow(prodRow, left[i], right);
+            }
+        });
+
+    }
 
     public static <N extends Scalar<N>> MultiplyNeither.Generic<N> newGeneric(final long rows, final long columns) {
         if (rows > THRESHOLD && columns > THRESHOLD) {
@@ -148,6 +172,13 @@ public class MultiplyNeither implements MatrixOperation {
         }
     }
 
+    private static void doOneRow(final double[] prodRow, final double[] leftRow, final double[][] right) {
+
+        for (int c = 0, complexity = leftRow.length; c < complexity; c++) {
+            AXPY.invoke(prodRow, leftRow[c], right[c]);
+        }
+    }
+
     static void add1xN(final double[] product, final double[] left, final int complexity, final double[] right) {
 
         for (int j = 0, nbCols = product.length; j < nbCols; j++) {
