@@ -90,6 +90,11 @@ public final class RowsSupplier<N extends Comparable<N>> implements MatrixStore<
         myRowFactory = SparseArray.factory(factory.array());
     }
 
+    @Override
+    public void add(final int row, final int col, final double addend) {
+        myRows.get(row).add(col, addend);
+    }
+
     @Override
     public void add(final long row, final long col, final Comparable<?> addend) {
         myRows.get((int) row).add(col, addend);
@@ -385,10 +390,23 @@ public final class RowsSupplier<N extends Comparable<N>> implements MatrixStore<
 
     @Override
     public R064CSR toCSR() {
+        return this.toCSR(this.getRowDim(), this.getColDim(), this.countNonzeros());
+    }
 
-        int nbRows = this.getRowDim();
-        int nbCols = this.getColDim();
-        int nbNz = this.countNonzeros();
+    @Override
+    public String toString() {
+        return Access2D.toString(this);
+    }
+
+    SparseArray<N> addRow(final SparseArray<N> rowToAdd) {
+        if (myRows.add(rowToAdd)) {
+            return rowToAdd;
+        } else {
+            return null;
+        }
+    }
+
+    R064CSR toCSR(final int nbRows, final int nbCols, final int nbNz) {
 
         double[] values = new double[nbNz];
         int[] colIndices = new int[nbNz];
@@ -409,17 +427,4 @@ public final class RowsSupplier<N extends Comparable<N>> implements MatrixStore<
         return new R064CSR(nbRows, nbCols, values, colIndices, rowPointers);
     }
 
-    @Override
-    public String toString() {
-        return Access2D.toString(this);
-    }
-
-    SparseArray<N> addRow(final SparseArray<N> rowToAdd) {
-        if (myRows.add(rowToAdd)) {
-            return rowToAdd;
-        } else {
-            return null;
-        }
-    }
-
 }
