@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -25,70 +25,77 @@ import static org.ojalgo.function.constant.PrimitiveMath.*;
 
 import java.util.List;
 import java.util.concurrent.atomic.AtomicInteger;
-import java.util.function.IntSupplier;
 
-import org.ojalgo.RecoverableCondition;
 import org.ojalgo.concurrent.DivideAndConquer;
 import org.ojalgo.concurrent.DivideAndConquer.Conquerer;
 import org.ojalgo.concurrent.Parallelism;
 import org.ojalgo.concurrent.ProcessingService;
 import org.ojalgo.equation.Equation;
-import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.structure.Access2D;
 import org.ojalgo.type.context.NumberContext;
 
 /**
- * Experimental parallelised version of {@link GaussSeidelSolver}.
- *
- * @author apete
+ * Experimental parallelised stationary iteration based on Gauss–Seidel-style in-place updates.
+ * <p>
+ * Concurrency and convergence
+ * <ul>
+ * <li>Targets systems where diagonal dominance or SPD structure makes Gauss–Seidel-type updates effective.
+ * <li>Parallel execution may introduce small differences compared to strictly sequential updates.
+ * </ul>
+ * Configuration
+ * <ul>
+ * <li>Ignores any configured {@link Preconditioner}; use the relaxation factor to influence convergence.
+ * </ul>
+ * When to use
+ * <ul>
+ * <li>To utilise multiple cores for simple in-place iterative sweeps.
+ * <li>As a smoother or pre-relaxation when approximate iterations are acceptable.
+ * <li>For challenging SPD problems prioritising convergence speed/robustness, Krylov methods are often
+ * preferable.
+ * </ul>
  */
-public final class ParallelGaussSeidelSolver extends StationaryIterativeSolver implements IterativeSolverTask.SparseDelegate {
+public final class ParallelGaussSeidelSolver extends IterativeSolverTask {
 
-    private static final DivideAndConquer.Divider DIVIDER = ProcessingService.INSTANCE.divider();
-    private static final IntSupplier PARALLELISM = Parallelism.CORES;
-    private static final int THRESHOLD = 128;
+    private static final DivideAndConquer.Divider DIVIDER = ProcessingService.INSTANCE.newDivider().parallelism(Parallelism.CORES).threshold(128);
 
     private static void divide(final int nbEquations, final Conquerer conquerer) {
-        DIVIDER.parallelism(PARALLELISM).threshold(THRESHOLD).divide(0, nbEquations, conquerer);
+        DIVIDER.divide(0, nbEquations, conquerer);
     }
 
     public ParallelGaussSeidelSolver() {
         super();
     }
 
+    @Override
     public double resolve(final List<Equation> equations, final PhysicalStore<Double> solution) {
 
-        int nbEquations = equations.size();
+        if (this.isDebugPrinterSet()) {
+            this.debug(0, NaN, solution);
+        }
+
+        int m = equations.size();
+
+        AtomicInteger iterationsCounter = new AtomicInteger();
 
         double tmpNorm = ZERO;
-        for (int r = 0; r < nbEquations; r++) {
+        for (int r = 0; r < m; r++) {
             tmpNorm = HYPOT.invoke(tmpNorm, equations.get(r).getRHS());
         }
         double normRHS = tmpNorm;
 
-        AtomicInteger iterationsCounter = new AtomicInteger();
+        ParallelGaussSeidelSolver.divide(m, (first, limit) -> this.resolve(equations, solution, normRHS, iterationsCounter, first, limit));
 
-        ParallelGaussSeidelSolver.divide(nbEquations, (first, last) -> this.resolve(equations, solution, normRHS, iterationsCounter, first, last));
-
-        return this.resolve(equations, solution, normRHS, iterationsCounter, 0, nbEquations);
-    }
-
-    public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> current) throws RecoverableCondition {
-
-        List<Equation> equations = IterativeSolverTask.toListOfRows(body, rhs);
-
-        this.resolve(equations, current);
-
-        return current;
+        return this.resolve(equations, solution, normRHS, iterationsCounter, 0, m);
     }
 
     private double resolve(final List<Equation> equations, final PhysicalStore<Double> solution, final double normRHS, final AtomicInteger iterationsCounter,
-            final int first, final int last) {
+            final int first, final int limit) {
 
         int iterationsLimit = this.getIterationsLimit();
+
         NumberContext accuracy = this.getAccuracyContext();
-        double relaxationFactor = this.getRelaxationFactor();
+
+        double relaxation = this.getRelaxationFactor();
 
         double normErr = POSITIVE_INFINITY;
 
@@ -96,8 +103,8 @@ public final class ParallelGaussSeidelSolver extends StationaryIterativeSolver i
 
             normErr = ZERO;
 
-            for (int r = first; r < last; r++) {
-                normErr = HYPOT.invoke(normErr, equations.get(r).adjust(solution, relaxationFactor));
+            for (int r = first; r < limit; r++) {
+                normErr = HYPOT.invoke(normErr, equations.get(r).adjust(solution, relaxation));
             }
 
             iterationsCounter.incrementAndGet();
@@ -106,9 +113,9 @@ public final class ParallelGaussSeidelSolver extends StationaryIterativeSolver i
                 this.debug(iterationsCounter.intValue(), normErr / normRHS, solution);
             }
 
-        } while ((iterationsCounter.intValue() < iterationsLimit) && !accuracy.isSmall(normRHS, normErr));
+        } while (iterationsCounter.intValue() < iterationsLimit && !Double.isNaN(normErr) && !accuracy.isSmall(normRHS, normErr));
 
-        return normErr / normRHS;
+        return accuracy.isZero(normRHS) ? normErr : normErr / normRHS;
     }
 
-}
+}
\ No newline at end of file
