@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,6 +21,8 @@
  */
 package org.ojalgo.optimisation;
 
+import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
+
 import java.math.BigDecimal;
 import java.math.BigInteger;
 import java.math.RoundingMode;
@@ -31,6 +33,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Objects;
 import java.util.Set;
 
 import org.ojalgo.ProgrammingError;
@@ -50,28 +53,50 @@ import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
+import org.ojalgo.structure.Primitive1D;
 import org.ojalgo.structure.Structure1D;
 import org.ojalgo.structure.Structure1D.IntIndex;
 import org.ojalgo.structure.Structure2D.IntRowColumn;
 import org.ojalgo.type.context.NumberContext;
 
 /**
+ * Expression represents a mathematical expression in the optimization model that can serve as either a
+ * constraint or a component of the objective function.
  * <p>
- * Think of an Expression as one constraint or a component to the objective function. An expression becomes a
- * linear expression as soon as you set a linear factor. Setting a quadratic factor turns it into a quadratic
- * expression. If you set both linear and quadratic factors it is a compound expression, and if you set
- * neither it is an empty expression. Currently the solvers supplied by ojAlgo can only handle linear
- * constraint expressions. The objective function can be linear, quadratic or compound. Empty expressions
- * makes no sense...
- * </p>
+ * An Expression can be:
+ * <ul>
+ * <li>Linear: Contains only linear terms (variable coefficients)</li>
+ * <li>Quadratic: Contains quadratic terms (products of variables)</li>
+ * <li>Compound: Contains both linear and quadratic terms</li>
+ * </ul>
  * <p>
- * An expression is turned into a constraint by setting a lower and/or upper limit. Use
- * {@linkplain Expression#lower(Comparable)}, {@linkplain Expression#upper(Comparable)} or
- * {@linkplain Expression#level(Comparable)}. An expression is made part of (contributing to) the objective
- * function by setting a contribution weight. Use {@linkplain Expression#weight(Comparable)}. The contribution
- * weight can be set to anything except zero (0.0). Often you may just want to set it to one (1.0). Other
- * values can be used to balance multiple expressions contributing to the objective function.
- * </p>
+ * Basic usage:
+ * <ul>
+ * <li>Set coefficients for variables with {@link #set(Variable, Comparable)} or
+ * {@link #add(Variable, Comparable)} methods</li>
+ * <li>Create quadratic terms with {@link #set(Variable, Variable, Comparable)} methods</li>
+ * <li>Create constraints by setting lower/upper bounds using {@link #lower(Comparable)},
+ * {@link #upper(Comparable)}, or {@link #level(Comparable)} for equality constraints</li>
+ * <li>Contribute to the objective function by setting a weight using {@link #weight(Comparable)}</li>
+ * </ul>
+ * <p>
+ * Advanced features include:
+ * <ul>
+ * <li>Integer expression handling with automatic detection and constraint tightening</li>
+ * <li>Support for binary variables with specialized methods for detecting binary constraints</li>
+ * <li>Expression evaluation at specific variable values using {@link #evaluate(Access1D)}</li>
+ * <li>Compensation for fixed variables to simplify expressions during solving</li>
+ * <li>Numerical scaling for improved solver stability</li>
+ * <li>Convenient methods for creating common expression types (sums, distances, etc.)</li>
+ * <li>Conversion to various function types for integration with different solvers</li>
+ * </ul>
+ * <p>
+ * The Expression class provides a fluent interface for building expressions with method chaining. It also
+ * supports automatic handling of numerical stability issues through scaling adjustments.
+ * <p>
+ * Note that while the Expression class supports quadratic terms in constraints, some solvers may only support
+ * linear constraints. Quadratic, linear, or compound expressions can typically be used in the objective
+ * function depending on the solver capabilities.
  *
  * @author apete
  */
@@ -91,14 +116,6 @@ public final class Expression extends ModelEntity<Expression> {
      */
     private final boolean myShallowCopy;
 
-    @SuppressWarnings("unused")
-    private Expression(final Expression entityToCopy) {
-
-        this(entityToCopy, null, false);
-
-        ProgrammingError.throwForIllegalInvocation();
-    }
-
     protected Expression(final Expression expressionToCopy, final ExpressionsBasedModel destinationModel, final boolean deep) {
 
         super(expressionToCopy);
@@ -146,6 +163,31 @@ public final class Expression extends ModelEntity<Expression> {
         myQuadratic = new HashMap<>();
     }
 
+    /**
+     * Adds the scaled values from another Expression to this Expression. The lower and upper limits/bounds,
+     * of either involved Expression, are not affected. Nor is the objective weight. Only the factors (linear
+     * and quadratic) are scaled and added.
+     * <P>
+     * This allows for constructs like:
+     *
+     * <pre>
+     * Expression expr1 = model.newExpression("Expr1");
+     * Expression expr2 = model.newExpression("Expr2");
+     * ...
+     * model.newExpression("Expr3").add(2.0, expr1).add(-3.0, expr2).lower(0.0);
+     * </pre>
+     */
+    public Expression add(final Comparable<?> scale, final Expression values) {
+        return this.doAdd(ModelEntity.toBigDecimal(scale), values);
+    }
+
+    /**
+     * @see #add(Comparable, Expression)
+     */
+    public Expression add(final double scale, final Expression values) {
+        return this.doAdd(BigDecimal.valueOf(scale), values);
+    }
+
     /**
      * @see #add(Variable, Comparable)
      */
@@ -188,6 +230,13 @@ public final class Expression extends ModelEntity<Expression> {
         return this.doAdd(this.toIntIndex(index), BigDecimal.valueOf(value));
     }
 
+    /**
+     * @see #add(Comparable, Expression)
+     */
+    public Expression add(final long scale, final Expression values) {
+        return this.doAdd(BigDecimal.valueOf(scale), values);
+    }
+
     /**
      * Will add the value to this variable's factor.
      */
@@ -371,6 +420,22 @@ public final class Expression extends ModelEntity<Expression> {
         }
     }
 
+    @Override
+    public boolean equals(final Object obj) {
+        if (this == obj) {
+            return true;
+        }
+        if (!super.equals(obj)) {
+            return false;
+        }
+        if (!(obj instanceof Expression)) {
+            return false;
+        }
+        Expression other = (Expression) obj;
+        return Objects.equals(myConstant, other.myConstant) && Objects.equals(myLinear, other.myLinear) && Objects.equals(myQuadratic, other.myQuadratic)
+                && myShallowCopy == other.myShallowCopy;
+    }
+
     public BigDecimal evaluate(final Access1D<BigDecimal> point) {
 
         BigDecimal retVal = this.getConstant();
@@ -471,6 +536,13 @@ public final class Expression extends ModelEntity<Expression> {
         return myQuadratic.keySet();
     }
 
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = super.hashCode();
+        return prime * result + Objects.hash(myConstant, myLinear, myQuadratic, myShallowCopy);
+    }
+
     public boolean isAnyLinearFactorNonZero() {
         return myLinear.size() > 0;
     }
@@ -620,7 +692,7 @@ public final class Expression extends ModelEntity<Expression> {
      * from the given point.
      *
      * @param variables The relevant variables
-     * @param point The point to measure from
+     * @param point     The point to measure from
      */
     public void setCompoundFactorsOffset(final List<Variable> variables, final Access1D<?> point) {
 
@@ -729,6 +801,16 @@ public final class Expression extends ModelEntity<Expression> {
         return value;
     }
 
+    private Expression doAdd(final BigDecimal scale, final Expression values) {
+        for (Entry<IntIndex, BigDecimal> entry : values.getLinearEntrySet()) {
+            this.doAdd(entry.getKey(), entry.getValue().multiply(scale));
+        }
+        for (Entry<IntRowColumn, BigDecimal> entry : values.getQuadraticEntrySet()) {
+            this.doAdd(entry.getKey(), entry.getValue().multiply(scale));
+        }
+        return this;
+    }
+
     private Expression doAdd(final IntIndex key, final BigDecimal value) {
 
         BigDecimal existing = myLinear.get(key);
@@ -839,7 +921,7 @@ public final class Expression extends ModelEntity<Expression> {
 
         builder.append(this.getName());
         builder.append(": ");
-        builder.append(display.enforce(this.toFunction().invoke(Access1D.asPrimitive1D(solution))));
+        builder.append(display.enforce(this.toFunction().invoke(Primitive1D.wrap(solution))));
 
         if (this.isObjective()) {
             builder.append(" (");
@@ -859,6 +941,17 @@ public final class Expression extends ModelEntity<Expression> {
         }
     }
 
+    /**
+     * Add all indices of referenced variables to the supplied {@link Set}.
+     */
+    void addAll(final Set<IntIndex> referenced) {
+        referenced.addAll(this.getLinearKeySet());
+        for (IntRowColumn quad : this.getQuadraticKeySet()) {
+            referenced.add(quad.row());
+            referenced.add(quad.column());
+        }
+    }
+
     void addObjectiveConstant(final BigDecimal value) {
 
         BigDecimal weight = this.getContributionWeight();
@@ -928,6 +1021,43 @@ public final class Expression extends ModelEntity<Expression> {
         return myQuadratic.size();
     }
 
+    double density() {
+
+        int nbVars = myModel.countVariables();
+
+        if (nbVars == 0) {
+
+            return ZERO;
+
+        } else {
+
+            if (this.isAnyQuadraticFactorNonZero()) {
+
+                int nbQuads = this.countQuadraticFactors();
+
+                double denom = nbVars * nbVars;
+
+                double numer = nbQuads;
+
+                return numer / denom;
+
+            } else if (this.isAnyLinearFactorNonZero()) {
+
+                int nbLins = this.countLinearFactors();
+
+                double denom = nbVars;
+
+                double numer = nbLins;
+
+                return numer / denom;
+
+            } else {
+
+                return ZERO;
+            }
+        }
+    }
+
     @Override
     int deriveAdjustmentExponent() {
 
@@ -936,14 +1066,31 @@ public final class Expression extends ModelEntity<Expression> {
         }
 
         AggregatorSet<BigDecimal> aggregators = BigAggregator.getSet();
-        AggregatorFunction<BigDecimal> largest = aggregators.largest();
-        AggregatorFunction<BigDecimal> smallest = aggregators.smallest();
+        AggregatorFunction<BigDecimal> largest = aggregators.maximum();
+        AggregatorFunction<BigDecimal> smallest = aggregators.minimum();
+
+        BigDecimal factor;
 
         if (this.isAnyQuadraticFactorNonZero()) {
 
-            for (BigDecimal quadraticFactor : myQuadratic.values()) {
-                largest.invoke(quadraticFactor);
-                smallest.invoke(quadraticFactor);
+            boolean onDiagonal = false;
+
+            for (Entry<IntRowColumn, BigDecimal> quadraticEntry : myQuadratic.entrySet()) {
+                IntRowColumn key = quadraticEntry.getKey();
+                if (key.row == key.column) {
+                    onDiagonal = true;
+                    factor = quadraticEntry.getValue().abs();
+                    largest.invoke(factor);
+                    smallest.invoke(factor);
+                }
+            }
+
+            if (!onDiagonal) {
+                for (BigDecimal quadraticFactor : myQuadratic.values()) {
+                    factor = quadraticFactor.abs();
+                    largest.invoke(factor);
+                    smallest.invoke(factor);
+                }
             }
 
             return ModelEntity.deriveAdjustmentExponent(largest, smallest, RANGE);
@@ -951,8 +1098,9 @@ public final class Expression extends ModelEntity<Expression> {
         } else if (this.isAnyLinearFactorNonZero()) {
 
             for (BigDecimal linearFactor : myLinear.values()) {
-                largest.invoke(linearFactor);
-                smallest.invoke(linearFactor);
+                factor = linearFactor.abs();
+                largest.invoke(factor);
+                smallest.invoke(factor);
             }
 
             return ModelEntity.deriveAdjustmentExponent(largest, smallest, RANGE);
@@ -1150,21 +1298,26 @@ public final class Expression extends ModelEntity<Expression> {
      */
     boolean isNegativeOn(final Set<IntIndex> subset) {
 
-        if (!this.isAnyQuadraticFactorNonZero()) {
+        if (this.isAnyQuadraticFactorNonZero()) {
+
+            return false;
+
+        } else {
+
             for (IntIndex index : subset) {
                 Variable setVar = myModel.getVariable(index);
                 int signum = myLinear.get(index).signum();
                 if (signum < 0 && setVar.isLowerLimitSet() && setVar.getLowerLimit().signum() >= 0) {
-
+                    continue;
                 } else if (signum > 0 && setVar.isUpperLimitSet() && setVar.getUpperLimit().signum() <= 0) {
-
+                    continue;
                 } else {
                     return false;
                 }
             }
-        }
 
-        return true;
+            return true;
+        }
     }
 
     /**
@@ -1174,21 +1327,26 @@ public final class Expression extends ModelEntity<Expression> {
      */
     boolean isPositiveOn(final Set<IntIndex> subset) {
 
-        if (!this.isAnyQuadraticFactorNonZero()) {
+        if (this.isAnyQuadraticFactorNonZero()) {
+
+            return false;
+
+        } else {
+
             for (IntIndex index : subset) {
                 Variable setVar = myModel.getVariable(index);
                 int signum = myLinear.get(index).signum();
                 if (signum > 0 && setVar.isLowerLimitSet() && setVar.getLowerLimit().signum() >= 0) {
-
+                    continue;
                 } else if (signum < 0 && setVar.isUpperLimitSet() && setVar.getUpperLimit().signum() <= 0) {
-
+                    continue;
                 } else {
                     return false;
                 }
             }
-        }
 
-        return true;
+            return true;
+        }
     }
 
     boolean isRedundant() {
