@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -38,6 +38,7 @@ import org.ojalgo.structure.Structure2D.IntRowColumn;
 abstract class FileFormatEBM {
 
     private static final String TAB = String.valueOf(ASCII.HT);
+    private static final String COMMENT = "*";
 
     private static Expression readExpression(final ExpressionsBasedModel model, final String[] fields) {
 
@@ -177,27 +178,32 @@ abstract class FileFormatEBM {
 
                 String[] fields = line.split(TAB);
 
+                if (line.isBlank() || line.startsWith(COMMENT)) {
+                    // Skip this line
+                    continue;
+                }
+
                 switch (line.charAt(0)) {
-                case 'V':
-                    FileFormatEBM.readVariable(retVal, fields);
-                    break;
-                case 'E':
-                    current = FileFormatEBM.readExpression(retVal, fields);
-                    break;
-                case 'L':
-                    if (current == null) {
+                    case 'V':
+                        FileFormatEBM.readVariable(retVal, fields);
+                        break;
+                    case 'E':
+                        current = FileFormatEBM.readExpression(retVal, fields);
+                        break;
+                    case 'L':
+                        if (current == null) {
+                            throw new IllegalStateException();
+                        }
+                        FileFormatEBM.readLinear(current, fields);
+                        break;
+                    case 'Q':
+                        if (current == null) {
+                            throw new IllegalStateException();
+                        }
+                        FileFormatEBM.readQuadratic(current, fields);
+                        break;
+                    default:
                         throw new IllegalStateException();
-                    }
-                    FileFormatEBM.readLinear(current, fields);
-                    break;
-                case 'Q':
-                    if (current == null) {
-                        throw new IllegalStateException();
-                    }
-                    FileFormatEBM.readQuadratic(current, fields);
-                    break;
-                default:
-                    throw new IllegalStateException();
                 }
             }
 
