@@ -34,7 +34,6 @@ import org.ojalgo.matrix.store.ElementsSupplier;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
 import org.ojalgo.matrix.store.R064Store;
-import org.ojalgo.matrix.task.iterative.ConjugateGradientSolver;
 import org.ojalgo.matrix.task.iterative.MutableSolver;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.scalar.PrimitiveScalar;
@@ -60,7 +59,7 @@ final class IterativeASS extends ActiveSetSolver {
      *
      * @author apete
      */
-    final class SchurComplementSolver extends MutableSolver<ConjugateGradientSolver> implements MatrixStore<Double> {
+    final class SchurComplementSolver extends MutableSolver {
 
         private final int myCountE = IterativeASS.this.countEqualityConstraints();
         private final SparseArrayPool myEquationBodyPool;
@@ -69,56 +68,13 @@ final class IterativeASS extends ActiveSetSolver {
 
         SchurComplementSolver() {
 
-            super(new ConjugateGradientSolver(), IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countInequalityConstraints());
-
-            // GaussSeidel
-            //this.setTerminationContext(NumberContext.getMath(MathContext.DECIMAL64).newPrecision(13));
-            //this.getDelegate().setRelaxationFactor(1.5);
-
-            // ConjugateGradient
-            this.setAccuracyContext(options.convex().iterative());
-            this.setIterationsLimit(myFullDim + myFullDim);
-
-            // this.setDebugPrinter(BasicLogger.DEBUG);
+            super(options.convex().newIterativeSolver(2 * (IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countInequalityConstraints())),
+                    IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countInequalityConstraints());
 
             myEquationBodyPool = new SparseArrayPool(myFullDim);
             myIterationRows = new Equation[myFullDim];
         }
 
-        @Override
-        public double doubleValue(final int row, final int col) {
-
-            int intRow = row;
-            int intCol = col;
-
-            if (intCol >= myCountE) {
-                int[] included = IterativeASS.this.getIncluded();
-                intCol = myCountE + included[intCol - myCountE];
-            }
-
-            return super.doubleValue(intRow, intCol);
-        }
-
-        @Override
-        public Double get(final int row, final int col) {
-            return Double.valueOf(this.doubleValue(row, col));
-        }
-
-        @Override
-        public int getColDim() {
-            return IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countIncluded();
-        }
-
-        @Override
-        public int getRowDim() {
-            return IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countIncluded();
-        }
-
-        @Override
-        public PhysicalStore.Factory<Double, ?> physical() {
-            return MATRIX_FACTORY;
-        }
-
         void add(final int j, final Access1D<Double> column, final double rhs) {
 
             int[] incl = IterativeASS.this.getIncluded();
@@ -130,7 +86,7 @@ final class IterativeASS extends ActiveSetSolver {
             if (myCountE > 0) {
                 for (int i = 0; i < myCountE; i++) {
                     double tmpVal = IterativeASS.this.getMatrixAE(i).dot(column);
-                    if (!PrimitiveScalar.isSmall(ONE, tmpVal)) {
+                    if (i == j || !PrimitiveScalar.isSmall(ONE, tmpVal)) {
                         Equation tmpRowE = myIterationRows[i];
                         if (tmpRowE != null) {
                             tmpRowE.set(j, tmpVal);
@@ -143,8 +99,8 @@ final class IterativeASS extends ActiveSetSolver {
             if (incl.length > 0) {
                 for (int _i = 0; _i < incl.length; _i++) {
                     double tmpVal = IterativeASS.this.getMatrixAI(incl[_i]).dot(column);
-                    if (!PrimitiveScalar.isSmall(ONE, tmpVal)) {
-                        int i = myCountE + incl[_i];
+                    int i = myCountE + incl[_i];
+                    if (i == j || !PrimitiveScalar.isSmall(ONE, tmpVal)) {
                         Equation tmpRowI = myIterationRows[i];
                         if (tmpRowI != null) {
                             tmpRowI.set(j, tmpVal);
@@ -152,12 +108,15 @@ final class IterativeASS extends ActiveSetSolver {
                         tmpNewRow.set(i, tmpVal);
                     }
                 }
-
             }
 
             tmpNewRow.initialise(IterativeASS.this.getSolutionL());
         }
 
+        double[] getRHS() {
+            return this.equations().mapToDouble(Equation::getRHS).toArray();
+        }
+
         void remove(final int i) {
 
             Equation rowI = myIterationRows[i];
@@ -333,4 +292,4 @@ final class IterativeASS extends ActiveSetSolver {
 
     }
 
-}
+}
\ No newline at end of file
