@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -37,7 +37,7 @@ public final class AnyTensor<N extends Comparable<N>> extends ArrayBasedTensor<N
 
         private final ArrayAnyD.Factory<N> myFactory;
 
-        Factory(final DenseArray.Factory<N> arrayFactory) {
+        Factory(final DenseArray.Factory<N, ?> arrayFactory) {
 
             super(arrayFactory);
 
@@ -113,7 +113,7 @@ public final class AnyTensor<N extends Comparable<N>> extends ArrayBasedTensor<N
 
     }
 
-    public static <N extends Comparable<N>> TensorFactoryAnyD<N, AnyTensor<N>> factory(final DenseArray.Factory<N> arrayFactory) {
+    public static <N extends Comparable<N>> TensorFactoryAnyD<N, AnyTensor<N>> factory(final DenseArray.Factory<N, ?> arrayFactory) {
         return new TensorFactoryAnyD<>(new AnyTensor.Factory<>(arrayFactory));
     }
 
