@@ -26,6 +26,7 @@ import java.io.InputStream;
 import java.math.BigDecimal;
 import java.math.MathContext;
 import java.util.Arrays;
+import java.util.Set;
 import java.util.function.IntSupplier;
 
 import org.junit.jupiter.api.Assertions;
@@ -34,14 +35,7 @@ import org.ojalgo.array.Array1D;
 import org.ojalgo.array.ArrayR064;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.function.special.MissingMath;
-import org.ojalgo.matrix.decomposition.Bidiagonal;
-import org.ojalgo.matrix.decomposition.Cholesky;
-import org.ojalgo.matrix.decomposition.Eigenvalue;
-import org.ojalgo.matrix.decomposition.Hessenberg;
-import org.ojalgo.matrix.decomposition.LU;
-import org.ojalgo.matrix.decomposition.QR;
-import org.ojalgo.matrix.decomposition.SingularValue;
-import org.ojalgo.matrix.decomposition.Tridiagonal;
+import org.ojalgo.matrix.decomposition.*;
 import org.ojalgo.matrix.operation.MatrixOperation;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
@@ -72,7 +66,7 @@ import org.ojalgo.type.context.NumberContext;
  *
  * @author apete
  */
-public abstract class TestUtils /* extends Assertions */ {
+public abstract class TestUtils {
 
     private static final NumberContext EQUALS = NumberContext.of(10);
 
@@ -85,6 +79,10 @@ public abstract class TestUtils /* extends Assertions */ {
 
     }
 
+    public static void assertArrayEquals(final double[] expected, final double[] actual, final double tolerance) {
+        Assertions.assertArrayEquals(expected, actual, tolerance);
+    }
+
     public static void assertArrayEquals(final long[] expected, final long[] actual) {
         Assertions.assertArrayEquals(expected, actual);
     }
@@ -173,6 +171,14 @@ public abstract class TestUtils /* extends Assertions */ {
         TestUtils.assertEquals("double != double", expected, actual, context);
     }
 
+    public static void assertEquals(final double expected, final double actual, final String message) {
+        TestUtils.assertEquals(message, expected, actual);
+    }
+
+    public static void assertEquals(final Double expected, final Double actual) {
+        TestUtils.assertEquals(expected, actual, EQUALS);
+    }
+
     public static void assertEquals(final double[] expected, final Access1D<?> actual, final NumberContext accuracy) {
         for (int p = 0; p < expected.length; p++) {
             TestUtils.assertEquals(expected[p], actual.doubleValue(p), accuracy);
@@ -238,6 +244,12 @@ public abstract class TestUtils /* extends Assertions */ {
         }
     }
 
+    public static <N extends Comparable<N>> void assertEquals(final MatrixStore<N> expected, final LDL<N> actual, final NumberContext context) {
+        if (!LDL.equals(expected, actual, context)) {
+            Assertions.fail(() -> "LDL<N> failed for " + expected);
+        }
+    }
+
     public static <N extends Comparable<N>> void assertEquals(final MatrixStore<N> expected, final LU<N> actual, final NumberContext context) {
         if (!LU.equals(expected, actual, context)) {
             Assertions.fail(() -> "LU<N> failed for " + expected);
@@ -436,6 +448,12 @@ public abstract class TestUtils /* extends Assertions */ {
         }
     }
 
+    public static <T> void assertInSet(final Set<T> allowed, final T actual) {
+        if (!allowed.contains(actual)) {
+            Assertions.fail(actual + " not contained in " + allowed);
+        }
+    }
+
     public static void assertLessThan(final double reference, final double actual) {
         if (actual >= reference) {
             Assertions.fail(actual + " !< " + reference);
@@ -464,6 +482,10 @@ public abstract class TestUtils /* extends Assertions */ {
         }
     }
 
+    public static void assertNotNull(final Object obj) {
+        Assertions.assertNotNull(obj);
+    }
+
     public static void assertNotNullOrEmpty(final String actual) {
         if (actual == null) {
             TestUtils.fail("Is null!");
