@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,6 +21,7 @@
  */
 package org.ojalgo.data.transform;
 
+import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.function.constant.ComplexMath;
@@ -31,7 +32,7 @@ import org.ojalgo.matrix.MatrixC128;
 import org.ojalgo.matrix.MatrixC128.DenseReceiver;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.random.Uniform;
 import org.ojalgo.scalar.ComplexNumber;
@@ -55,6 +56,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
     }
 
     @Test
+    @Tag("unstable")
     public void testCompareImplementationsUsingRandomInput() {
 
         NumberContext accuracy = NumberContext.of(8);
@@ -63,7 +65,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
 
             int dim = PowerOf2.powerOfInt2(power);
 
-            PhysicalStore<Double> input = Primitive64Store.FACTORY.makeFilled(dim, 1, Uniform.of(-2, 4));
+            PhysicalStore<Double> input = R064Store.FACTORY.makeFilled(dim, 1, Uniform.of(-2, 4));
 
             DiscreteFourierTransform full = new DiscreteFourierTransform.FullMatrix(dim);
             DiscreteFourierTransform fast = new DiscreteFourierTransform.FFT(dim);
@@ -191,7 +193,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
 
         MatrixC128 input = MatrixC128.FACTORY.column(0.0, 1.0, 2.0, 3.0);
 
-        DenseReceiver receiver = MatrixC128.FACTORY.makeDense(4, 1);
+        DenseReceiver receiver = MatrixC128.FACTORY.newDenseBuilder(4, 1);
         receiver.set(0, ComplexNumber.of(6, 0));
         receiver.set(1, ComplexNumber.of(-2, 2));
         receiver.set(2, ComplexNumber.of(-2, 0));
@@ -225,7 +227,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
 
         MatrixC128 input = MatrixC128.FACTORY.column(1.0, 1.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0);
 
-        DenseReceiver receiver = MatrixC128.FACTORY.makeDense(8, 1);
+        DenseReceiver receiver = MatrixC128.FACTORY.newDenseBuilder(8, 1);
         receiver.set(0, ComplexNumber.of(4, 0));
         receiver.set(1, ComplexNumber.of(1, -2.4142135623730945));
         receiver.set(2, ComplexNumber.of(0, 0));
@@ -280,7 +282,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
 
         for (int dimension = 2; dimension <= 16; dimension++) {
 
-            PhysicalStore<Double> input = Primitive64Store.FACTORY.makeFilled(dimension, 1, Uniform.of(-2, 4));
+            PhysicalStore<Double> input = R064Store.FACTORY.makeFilled(dimension, 1, Uniform.of(-2, 4));
 
             DiscreteFourierTransform transformer = DiscreteFourierTransform.newInstance(dimension);
 
@@ -303,7 +305,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
         for (int c = 2; c < 10; c += 2) {
             for (int r = 2; r < 10; r += 2) {
 
-                Primitive64Store original = Primitive64Store.FACTORY.make(r, c);
+                R064Store original = R064Store.FACTORY.make(r, c);
 
                 for (int j = 0; j < c; j++) {
                     for (int i = 0; i < r; i++) {
@@ -343,7 +345,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
         for (int c = 3; c < 10; c++) {
             for (int r = 3; r < 10; r++) {
 
-                Primitive64Store original = Primitive64Store.FACTORY.make(r, c);
+                R064Store original = R064Store.FACTORY.make(r, c);
 
                 for (int j = 0; j < c; j++) {
                     for (int i = 0; i < r; i++) {
@@ -377,7 +379,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
 
         MatrixC128 input = MatrixC128.FACTORY.column(0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0);
 
-        DenseReceiver receiver = MatrixC128.FACTORY.makeDense(8, 1);
+        DenseReceiver receiver = MatrixC128.FACTORY.newDenseBuilder(8, 1);
         receiver.set(0, ComplexNumber.of(28, 0));
         receiver.set(1, ComplexNumber.of(-4, 9.656854249492376));
         receiver.set(2, ComplexNumber.of(-4, 4));
@@ -421,7 +423,7 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
         ComplexNumber unitRoot = ComplexNumber.newUnitRoot(4);
         double unitRootPhase = unitRoot.phase();
 
-        DenseReceiver receiver = MatrixC128.FACTORY.makeDense(4, 4);
+        DenseReceiver receiver = MatrixC128.FACTORY.newDenseBuilder(4, 4);
         for (int j = 0; j < 4; j++) {
             for (int i = 0; i < 4; i++) {
                 receiver.set(i, j, ComplexNumber.makePolar(PrimitiveMath.ONE, i * j * unitRootPhase));
@@ -436,9 +438,9 @@ final class DiscreteFourierTransformTest extends DataTransformTests {
 
         DiscreteFourierTransform transform = DiscreteFourierTransform.newInstance(4);
 
-        MatrixC128 columnA = MatrixC128.FACTORY.columns(polynomialA);
+        MatrixC128 columnA = MatrixC128.FACTORY.column(polynomialA);
         MatrixC128 transfA = matrix.multiply(columnA);
-        MatrixC128 columnB = MatrixC128.FACTORY.columns(polynomialB);
+        MatrixC128 columnB = MatrixC128.FACTORY.column(polynomialB);
         MatrixC128 transfB = matrix.multiply(columnB);
 
         MatrixC128 transfC = transfA.onMatching(ComplexMath.MULTIPLY, transfB);
