@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,6 +22,7 @@
 package org.ojalgo.matrix;
 
 import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.matrix.decomposition.Eigenvalue;
@@ -79,6 +80,12 @@ public class P20061119Case extends BasicMatrixTest {
         TestUtils.assertEquals(true, P20061119Case.getProblematic().isSquare());
     }
 
+    @Tag("unstable")
+    @Override
+    public void testDotAccess1D() {
+        super.testDotAccess1D();
+    }
+
     @Override
     @Test
     public void testGetRank() {
