@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -47,10 +47,10 @@ public class CaseLDL extends MatrixDecompositionTests {
         TestUtils.assertEquals(mtrxA, reconstructed);
 
         // TODO Change to new RawLDL() when it's done
-        LDL<Double> rawLDL = new LDLDecomposition.R064();
+        LDL<Double> rawLDL = new DenseLDL.R064();
         rawLDL.decompose(mtrxA);
 
-        LDL<Double> primLDL = new LDLDecomposition.R064();
+        LDL<Double> primLDL = new DenseLDL.R064();
         primLDL.decompose(mtrxA.triangular(false, false));
 
         if (MatrixDecompositionTests.DEBUG) {
@@ -113,7 +113,7 @@ public class CaseLDL extends MatrixDecompositionTests {
     }
 
     private static boolean hasNegativeEigenvalue(MatrixStore<Double> mtrxA) {
-        Eigenvalue<Double> EVD = EigenvalueDecomposition.R064.make(mtrxA);
+        Eigenvalue<Double> EVD = DenseEigenvalue.R064.make(mtrxA);
         EVD.decompose(mtrxA);
         if (!EVD.isHermitian()) {
             //            This test was to sensitive
