@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,7 @@ package org.ojalgo.matrix.decomposition;
 import org.ojalgo.BenchmarkUtils;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.random.Uniform;
 import org.openjdk.jmh.annotations.Benchmark;
 import org.openjdk.jmh.annotations.Param;
@@ -96,27 +96,27 @@ public class PrimitiveOrRawQR extends AbstractPrimitiveOrRaw<QR<Double>> {
     public static final class CodeAndData {
 
         public static QR<Double> newInstance(final int dim) {
-            return QR.PRIMITIVE.make(2 * dim, dim);
+            return QR.R064.make(2 * dim, dim);
         }
 
         public static QR<Double> newPrimitive() {
-            return new QRDecomposition.R064();
+            return new DenseQR.R064();
         }
 
         public static QR<Double> newRaw() {
             return new RawQR();
         }
 
-        final Primitive64Store body;
+        final R064Store body;
         transient PhysicalStore<Double> preallocated = null;
-        final Primitive64Store rhs;
+        final R064Store rhs;
 
         public CodeAndData(final int dim) {
 
             super();
 
-            body = Primitive64Store.FACTORY.makeFilled(2 * dim, dim, Uniform.standard());
-            rhs = Primitive64Store.FACTORY.makeFilled(2 * dim, 1, Uniform.standard());
+            body = R064Store.FACTORY.makeFilled(2 * dim, dim, Uniform.standard());
+            rhs = R064Store.FACTORY.makeFilled(2 * dim, 1, Uniform.standard());
         }
 
         public MatrixStore<Double> execute(final QR<Double> decomposition) {
@@ -161,7 +161,7 @@ public class PrimitiveOrRawQR extends AbstractPrimitiveOrRaw<QR<Double>> {
 
     @Override
     protected QR<Double> makePrimitive() {
-        return new QRDecomposition.R064();
+        return new DenseQR.R064();
     }
 
     @Override
