@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -63,6 +63,10 @@ public class LinearProblems extends OptimisationLinearTests {
         Optimisation.Result result = Result.of(8.5755E8, State.OPTIMAL, 7.84804E+8, 0, 0, 7.2746E+7);
 
         ExpressionsBasedModel model = ModelFileTest.makeModel("usersupplied", "GitHub546.ebm", false);
+        // The old/classic solver cannot handle this problem.
+        // (That was the original bug report.)
+        // Have to force use of the newer dual solver.
+        model.options.linear().dual();
 
         return OptimisationCase.of(model, Sense.MIN, result);
     }
@@ -252,6 +256,33 @@ public class LinearProblems extends OptimisationLinearTests {
         TestUtils.assertEquals(0, claimedValue.compareTo(tmpFullValue));
     }
 
+    /**
+     * https://github.com/vagmcs/Optimus/issues/43
+     * <p>
+     * The problem is unbounded (not infeasible). A feasible solution is x=120 and y=80.
+     * <p>
+     * In this case ojAlgo finds a feasible solution, but then somehow fails to identify that it's unbounded
+     * and instead returns a solution with an infinite value.
+     */
+    @Test
+    public void testOptimus43() {
+
+        ExpressionsBasedModel model = new ExpressionsBasedModel();
+
+        if (DEBUG) {
+            model.options.debug(LinearSolver.class);
+        }
+
+        Variable x = model.newVariable("x").weight(-2);
+        Variable y = model.newVariable("y").lower(80).upper(170).weight(5);
+
+        model.addExpression().set(x, 1).set(y, 1).lower(200);
+
+        Result result = model.minimise();
+
+        TestUtils.assertEquals(State.UNBOUNDED, result.getState());
+    }
+
     /**
      * Didn't recognise this as an infeasible problem.
      */
