@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -181,6 +181,25 @@ public class RevisedSimplexSolverTest extends OptimisationLinearTests {
         }
     }
 
+    @Test
+    public void testCaseFromChat() {
+
+        Optimisation.Result expected = Optimisation.Result.of(9, Optimisation.State.OPTIMAL, 3, 0);
+
+        ExpressionsBasedModel model = new ExpressionsBasedModel();
+
+        Variable x1 = model.addVariable("x1").lower(0).weight(3);
+        Variable x2 = model.addVariable("x2").lower(0).weight(2);
+
+        model.addExpression().set(x1, -1).set(x2, 2).upper(4);
+        model.addExpression().set(x1, 2).set(x2, 1).lower(6);
+        model.addExpression().set(x1, 1).set(x2, 1).level(3);
+
+        RevisedSimplexSolverTest.doTestDualVariants(model, expected);
+
+        RevisedSimplexSolverTest.doTestPhasedVariants(model, expected);
+    }
+
     /**
      * https://people.math.carleton.ca/~kcheung/math/notes/MATH5801/06/6_3_revised_dual_simplex.html
      */
@@ -312,7 +331,7 @@ public class RevisedSimplexSolverTest extends OptimisationLinearTests {
         model.addExpression().add(v0, 1).add(v1, 1).level(5);
         model.addExpression().add(v2, 1).lower(-10);
 
-        // 5, 0, -10 and 0, 5, -10 (or any linear kombination) are both optimal
+        // 5, 0, -10 and 0, 5, -10 (or any linear combination) are both optimal
         Optimisation.Result expected = Optimisation.Result.of(-10, State.OPTIMAL, 5, 0, -10);
 
         RevisedSimplexSolverTest.doTestPhasedVariants(model, expected);
@@ -522,9 +541,9 @@ public class RevisedSimplexSolverTest extends OptimisationLinearTests {
 
         Optimisation.Result expected = Result.of(State.OPTIMAL, 0.0, 2.0, 2.0, 0.0);
 
-        RevisedSimplexSolverTest.doTestPrimalVariants(builder, expected, 0, 1);
-
         RevisedSimplexSolverTest.doTestPhasedVariants(builder, expected);
+
+        RevisedSimplexSolverTest.doTestPrimalVariants(builder, expected, 0, 1);
     }
 
     /**
