@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,6 +21,7 @@
  */
 package org.ojalgo.tensor;
 
+import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.array.ArrayAnyD;
@@ -144,6 +145,7 @@ public class TensorTest {
     }
 
     @Test
+    @Tag("unstable")
     public void testDeterminantAndTrace() {
 
         MatrixTensor<RationalNumber> tensorA = FACTORY_2.copy(ELEMENTS_A);
